@@ -1013,7 +1013,7 @@ static int hook_request_late(request_rec *r) {
     }
 
     rc = read_request_body(msr, &my_error_msg);
-    if (rc < 0) {
+    if (rc < 0 && msr->txcfg->is_enabled == MODSEC_ENABLED) {
         switch(rc) {
             case -1 :
                 if (my_error_msg != NULL) {
@@ -1597,7 +1597,7 @@ static int hook_connection_early(conn_rec *conn)
                     "Possible DoS Consumption Attack [Rejected]", ip_count_w,
                     conn_write_state_limit, client_ip);
 
-                if (!conn_limits_filter_state == MODSEC_ENABLED)
+                if (conn_limits_filter_state == MODSEC_ENABLED)
                     return OK;
             }
         }
